#off allint_old <- allint
#off rm(list=grep("allint_old", ls(), invert=T, value=T))

#load helper
lix <- function(x) readxl::read_xlsx("files/Lista_monti.xlsx", sheet = x)
# separate gene names in rows

# join files
imp <- function(x, y_, z) {
  print("x must be xls file!")
  y <- separate_rows(y_, Gene.names, sep = " ")
  left_join(x, y, by = c("Gene name" = "Gene.names", "Uniprot" = "Entry")) %>%
  select(Uniprot, "Protein name",
         "Gene Symbol" = "Gene name",
         DrugBank = Cross.reference..DrugBank.,
         scl = Subcellular.location..CC.) %>%
  mutate(Species = z, .before = everything())
}

#helper for clipboard
imp3 <- function(x, dv) {
    x %>%
    separate_rows(DrugBank, sep = ";") %>%
    filter(DrugBank != "") %>%
    left_join(dv) %>%
    select(-c(`Endogenous GLA`:Replagal)) %>%
    write.csv(pipe("xsel -b"), row.names = FALSE, quote = TRUE)
}

library(tidyverse)

# load interactomes
xlsxs <- lapply(1:3, lix)
names(xlsxs) <- c("vanilla", "fabrazy", "replaga")

# Enrich interactomes UIDs with Drug association and SubCellular location
# (using the Uniprot column from the xlsx tables)
files <- c("files/48_vanilla.tab",
           "files/112_fabrazyme.tab",
           "files/99_replagal.tab")
unilist <-   lapply(files, read.delim)
names(unilist) <- c("vanilla", "fabrazy", "replaga")

# temporary tables with all infos, separated by treatment
vanilla_glob <- imp(xlsxs$vanilla, unilist$vanilla, "Endogenous GLA")
fabrazy_glob <- imp(xlsxs$fabrazy, unilist$fabrazy, "Fabrazyme")
replaga_glob <- imp(xlsxs$replaga, unilist$replaga, "Replagal")

# get from drugbank drugbank id <-> common name dictionary
# (https://go.drugbank.com/releases/latest#open-data)
drug_vocab_raw <- read.csv(file = "files/drugbank vocabulary.csv")
drug_vocab <- drug_vocab_raw %>% select(DrugBank = DrugBank.ID, Common.name)

#Merge of all tables and dbid to common name conversion
allint <- bind_rows(vanilla_glob, fabrazy_glob, replaga_glob) %>%
            mutate(dummy = TRUE) %>%
            pivot_wider(names_from = Species, values_from = dummy) %>%
            filter(DrugBank != "") %>%
            select(-scl)

#List saved as sup xlsx table (on drive ERT/interactome/druggable_itneractome)
# druggable interactors shared among the three
  allint %>%
    filter(`Endogenous GLA`, Fabrazyme, Replagal) %>%
    imp3(drug_vocab)

# replagal&fabrazyme druggable interactors
  allint %>%
    filter(is.na(`Endogenous GLA`), Fabrazyme, Replagal) %>%
    imp3(drug_vocab)

# endogen druggable interactors
  allint %>%
    filter(`Endogenous GLA`) %>%
    imp3(drug_vocab)
